package org.apache.bcel.generic;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.util.ByteSequence;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/IINC.class */
public class IINC extends LocalVariableInstruction {
    private boolean wide;
    private int c;

    /* JADX INFO: Access modifiers changed from: package-private */
    public IINC() {
    }

    public IINC(int n, int c) {
        super.setOpcode((short) 132);
        super.setLength(3);
        setIndex(n);
        setIncrement(c);
    }

    @Override // org.apache.bcel.generic.Instruction
    public void accept(Visitor v) {
        v.visitLocalVariableInstruction(this);
        v.visitIINC(this);
    }

    @Override // org.apache.bcel.generic.LocalVariableInstruction, org.apache.bcel.generic.Instruction
    public void dump(DataOutputStream out) throws IOException {
        if (this.wide) {
            out.writeByte(196);
        }
        out.writeByte(super.getOpcode());
        if (this.wide) {
            out.writeShort(super.getIndex());
            out.writeShort(this.c);
        } else {
            out.writeByte(super.getIndex());
            out.writeByte(this.c);
        }
    }

    public final int getIncrement() {
        return this.c;
    }

    @Override // org.apache.bcel.generic.LocalVariableInstruction, org.apache.bcel.generic.TypedInstruction
    public Type getType(ConstantPoolGen cp) {
        return Type.INT;
    }

    @Override // org.apache.bcel.generic.LocalVariableInstruction, org.apache.bcel.generic.Instruction
    protected void initFromFile(ByteSequence bytes, boolean wide) throws IOException {
        this.wide = wide;
        if (wide) {
            super.setLength(6);
            super.setIndexOnly(bytes.readUnsignedShort());
            this.c = bytes.readShort();
        } else {
            super.setLength(3);
            super.setIndexOnly(bytes.readUnsignedByte());
            this.c = bytes.readByte();
        }
    }

    public final void setIncrement(int c) {
        this.c = c;
        setWide();
    }

    @Override // org.apache.bcel.generic.LocalVariableInstruction, org.apache.bcel.generic.IndexedInstruction
    public final void setIndex(int n) {
        if (n < 0) {
            throw new ClassGenException("Negative index value: " + n);
        }
        super.setIndexOnly(n);
        setWide();
    }

    private void setWide() {
        this.wide = super.getIndex() > 255;
        if (this.c > 0) {
            this.wide = this.wide || this.c > 127;
        } else {
            this.wide = this.wide || this.c < -128;
        }
        if (this.wide) {
            super.setLength(6);
        } else {
            super.setLength(3);
        }
    }

    @Override // org.apache.bcel.generic.LocalVariableInstruction, org.apache.bcel.generic.Instruction
    public String toString(boolean verbose) {
        return super.toString(verbose) + " " + this.c;
    }
}
